@@ -2,7 +2,12 @@
 """Numpoly -- Multivariate polynomials as numpy elements."""
 import logging
 import os
-import pkg_resources
+import sys
+
+if sys.version_info >= (3, 10):
+    from importlib import metadata as importlib_metadata
+else:
+    import importlib_metadata
 
 from .baseclass import ndpoly, FeatureNotSupported, PolyLike
 
@@ -49,11 +54,10 @@ def get_version(name: str) -> str:
         True
 
     """
-    version = ""
     try:
-        version = pkg_resources.get_distribution(name).version
-    except pkg_resources.DistributionNotFound:
-        pass
+        version = importlib_metadata.version(name)
+    except importlib_metadata.PackageNotFoundError:
+        version = ""
     return version
 
 
