@@ -11,10 +11,10 @@ from ..dispatch import implements, simple_dispatch
 
 @implements(numpy.isfinite)
 def isfinite(
-        x: PolyLike,
-        out: Optional[numpy.ndarray] = None,
-        where: numpy.typing.ArrayLike = True,
-        **kwargs: Any,
+    x: PolyLike,
+    out: Optional[numpy.ndarray] = None,
+    where: numpy.typing.ArrayLike = True,
+    **kwargs: Any,
 ) -> numpy.ndarray:
     """
     Test element-wise for finiteness (not infinity or not Not a Number).
@@ -40,15 +40,15 @@ def isfinite(
         kwargs:
             Keyword args passed to numpy.ufunc.
 
-    Returns:
+    Return:
         True where ``x`` is not positive infinity, negative infinity, or NaN;
         false otherwise. This is a scalar if `x` is a scalar.
 
-    Notes:
+    Note:
         Not a Number, positive infinity and negative infinity are considered to
         be non-finite.
 
-    Examples:
+    Example:
         >>> numpoly.isfinite(1)
         True
         >>> numpoly.isfinite(0)
@@ -64,10 +64,7 @@ def isfinite(
 
     """
     out_ = simple_dispatch(
-        numpy_func=numpy.isfinite,
-        inputs=(x,),
-        where=where,
-        **kwargs
+        numpy_func=numpy.isfinite, inputs=(x,), where=where, **kwargs
     )
     if out is None:
         out_ = numpy.all(numpy.asarray(out_.coefficients), axis=0)
